Stan Math Library: stan/math/prim/scal/prob/scaled_inv_chi_square_rng.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

scaled_inv_chi_square_rng.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_PROB_SCALED_INV_CHI_SQUARE_RNG_HPP
2 #define STAN_MATH_PRIM_SCAL_PROB_SCALED_INV_CHI_SQUARE_RNG_HPP
3
4 #include <boost/random/chi_squared_distribution.hpp>
5 #include <boost/random/variate_generator.hpp>
6 #include <stan/math/prim/scal/err/check_consistent_sizes.hpp>
7 #include <stan/math/prim/scal/err/check_nonnegative.hpp>
8 #include <stan/math/prim/scal/err/check_not_nan.hpp>
9 #include <stan/math/prim/scal/err/check_positive_finite.hpp>
10 #include <stan/math/prim/scal/fun/constants.hpp>
11 #include <stan/math/prim/scal/fun/value_of.hpp>
12 #include <stan/math/prim/scal/fun/gamma_q.hpp>
13 #include <stan/math/prim/scal/fun/digamma.hpp>
14 #include <stan/math/prim/scal/fun/lgamma.hpp>
15 #include <stan/math/prim/scal/fun/square.hpp>
16 #include <stan/math/prim/scal/meta/VectorView.hpp>
17 #include <stan/math/prim/scal/meta/VectorBuilder.hpp>
18 #include <stan/math/prim/scal/meta/length.hpp>
19 #include <stan/math/prim/scal/meta/include_summand.hpp>
20 #include <stan/math/prim/scal/fun/grad_reg_inc_gamma.hpp>
21
22 namespace stan {
23
24 namespace math {
25
26 template <class RNG>
27 inline double
28 scaled_inv_chi_square_rng(const double nu,
29 const double s,
30 RNG& rng) {
31 using boost::variate_generator;
32 using boost::random::chi_squared_distribution;
33
34 static const char* function("stan::math::scaled_inv_chi_square_rng");
35
36 using stan::math::check_positive_finite;
37
38 check_positive_finite(function, "Degrees of freedom parameter", nu);
39 check_positive_finite(function, "Scale parameter", s);
40
41 variate_generator<RNG&, chi_squared_distribution<> >
42 chi_square_rng(rng, chi_squared_distribution<>(nu));
43 return nu * s / chi_square_rng();
44 }
45 }
46 }
47 #endif
check_not_nan.hpp
stan::math::scaled_inv_chi_square_rng
double scaled_inv_chi_square_rng(const double nu, const double s, RNG &rng)
Definition: scaled_inv_chi_square_rng.hpp:28
lgamma.hpp
stan::math::chi_square_rng
double chi_square_rng(const double nu, RNG &rng)
Definition: chi_square_rng.hpp:24
check_positive_finite.hpp
stan
Definition: log_sum_exp.hpp:8
digamma.hpp
square.hpp
gamma_q.hpp
include_summand.hpp
check_nonnegative.hpp
VectorView.hpp
VectorBuilder.hpp
length.hpp
grad_reg_inc_gamma.hpp
constants.hpp
value_of.hpp
check_consistent_sizes.hpp
stan::math::check_positive_finite
bool check_positive_finite(const char *function, const char *name, const T_y &y)
Return true if y is positive and finite.
Definition: check_positive_finite.hpp:28

[ Stan Home Page ] © 2011–2016, Stan Development Team.